==> ejc-accplat-impl-3.0.0-20231229.082139-55-sources.jar: com/ejianc/business/accplat/config/bean/AuxiliaryEntity.java <==
package com.ejianc.business.accplat.config.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 辅助核算项
 * 
 * @author generator
 * 
 */
 @TableName("ejc_accplat_auxiliary")
public class AuxiliaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="auxiliary_code")
    private String auxiliaryCode; // 编码
    @TableField(value="auxiliary_name")
    private String auxiliaryName; // 名称
    @TableField(value="refer_id")
    private Long referId; // 档案id
    @TableField(value="refer_code")
    private String referCode; // 档案参照编码
    @TableField(value="refer_name")
    private String referName; // 档案参照名称
    @TableField(value="data_type")
    private Integer dataType; // 数据类型1基础档案2自定义档案
    @TableField(value="enabled")
    private Integer enabled; // 启用状态1启用0停用


    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }

    public String getAuxiliaryCode() {
        return auxiliaryCode;
    }

    public void setAuxiliaryCode(String auxiliaryCode) {
        this.auxiliaryCode = auxiliaryCode;
    }
    public String getAuxiliaryName() {
        return auxiliaryName;
    }

    public void setAuxiliaryName(String auxiliaryName) {
        this.auxiliaryName = auxiliaryName;
    }

    public Long getReferId() {
        return referId;
    }

    public void setReferId(Long referId) {
        this.referId = referId;
    }
    public String getReferCode() {
        return referCode;
    }

    public void setReferCode(String referCode) {
        this.referCode = referCode;
    }
    public String getReferName() {
        return referName;
    }

    public void setReferName(String referName) {
        this.referName = referName;
    }
    public Integer getDataType() {
        return dataType;
    }

    public void setDataType(Integer dataType) {
        this.dataType = dataType;
    }
    
}

==> ejc-accplat-impl-3.0.0-20240229.085127-171-sources.jar: com/ejianc/business/accplat/config/bean/AuxiliaryEntity.java <==
package com.ejianc.business.accplat.config.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 辅助核算项
 * 
 * @author generator
 * 
 */
 @TableName("ejc_accplat_auxiliary")
public class AuxiliaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="auxiliary_code")
    private String auxiliaryCode; // 编码
    @TableField(value="auxiliary_name")
    private String auxiliaryName; // 名称
    @TableField(value="refer_id")
    private Long referId; // 档案id
    @TableField(value="refer_code")
    private String referCode; // 档案参照编码
    @TableField(value="refer_name")
    private String referName; // 档案参照名称
    @TableField(value="data_type")
    private Integer dataType; // 数据类型1基础档案2自定义档案
    @TableField(value="enabled")
    private Integer enabled; // 启用状态1启用0停用
    @TableField(value="compare_app_id")
    private Long compareAppId; // 对照数据id
    @TableField(value="compare_app_name")
    private String compareAppName; // 对照数据编码


    public Long getCompareAppId() {
        return compareAppId;
    }

    public void setCompareAppId(Long compareAppId) {
        this.compareAppId = compareAppId;
    }

    public String getCompareAppName() {
        return compareAppName;
    }

    public void setCompareAppName(String compareAppName) {
        this.compareAppName = compareAppName;
    }

    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }

    public String getAuxiliaryCode() {
        return auxiliaryCode;
    }

    public void setAuxiliaryCode(String auxiliaryCode) {
        this.auxiliaryCode = auxiliaryCode;
    }
    public String getAuxiliaryName() {
        return auxiliaryName;
    }

    public void setAuxiliaryName(String auxiliaryName) {
        this.auxiliaryName = auxiliaryName;
    }

    public Long getReferId() {
        return referId;
    }

    public void setReferId(Long referId) {
        this.referId = referId;
    }
    public String getReferCode() {
        return referCode;
    }

    public void setReferCode(String referCode) {
        this.referCode = referCode;
    }
    public String getReferName() {
        return referName;
    }

    public void setReferName(String referName) {
        this.referName = referName;
    }
    public Integer getDataType() {
        return dataType;
    }

    public void setDataType(Integer dataType) {
        this.dataType = dataType;
    }
    
}
